[![CI](https://github.com/ARGOS-telescope/argosim/actions/workflows/ci-build.yml/badge.svg)](https://github.com/ARGOS-telescope/argosim/actions/workflows/ci-build.yml)
[![docs](https://img.shields.io/badge/docs-Sphinx-blue)](https://argos-telescope.github.io/argosim/)
[![pypi](https://img.shields.io/pypi/v/argosim)](https://pypi.org/project/argosim/)
[![License](https://img.shields.io/badge/License-MIT-brigthgreen.svg)](https://github.com/ARGOS-telescope/argosim/blob/main/LICENSE) 

# Argosim
Argosim is a python package for radio interferometric observation simulations and image reconstruction.

See the [documentation](https://argos-telescope.github.io/argosim/) for installing and running Argosim.

Software developed at the [CosmoStat](https://www.cosmostat.org/) laboratory, CEA, Paris-Saclay, for the [ARGOS](https://argos-telescope.eu) telescope.
